pub struct DiscoveryChannelConfig {
pub grpc: GrpcClientConfig,
pub resolve_interval: Duration,
}Expand description
Configuration for a DiscoveryChannel.
Fields
grpc: GrpcClientConfigBase gRPC client configuration.
resolve_interval: DurationHow often to poll for changes when no watcher is available. Defaults to 10 seconds.
Implementations
Sourceimpl DiscoveryChannelConfig
impl DiscoveryChannelConfig
Sourcepub fn new(grpc: GrpcClientConfig) -> Self
pub fn new(grpc: GrpcClientConfig) -> Self
Create a config with defaults and the given gRPC settings.
Sourcepub fn with_resolve_interval(self, interval: Duration) -> Self
pub fn with_resolve_interval(self, interval: Duration) -> Self
Set the resolve polling interval.